==> ansible-9.0.1-1-any.pkg.tar.xz: usr/lib/python3.11/site-packages/ansible_collections/cisco/meraki/plugins/modules/networks_clients_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: networks_clients_info
short_description: Information module for networks _clients
description:
- Get networks _clients by id.
- >
   Return the client associated with the given identifier. Clients can be identified by a client key or either the
   MAC or IP depending on whether the network uses Track-by-IP.
version_added: '2.16.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  networkId:
    description:
    - NetworkId path parameter. Network ID.
    type: str
  clientId:
    description:
    - ClientId path parameter. Client ID.
    type: str
requirements:
- meraki >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco Meraki documentation for networks getNetworkClient
  description: Complete reference of the getNetworkClient API.
  link: https://developer.cisco.com/meraki/api-v1/#!get-network-client
notes:
  - SDK Method used are
    networks.Networks.get_network_client,

  - Paths used are
    get /networks/{networkId}/clients/{clientId},
"""

EXAMPLES = r"""
- name: Get networks _clients by id
  cisco.meraki.networks_clients_info:
    meraki_api_key: "{{meraki_api_key}}"
    meraki_base_url: "{{meraki_base_url}}"
    meraki_single_request_timeout: "{{meraki_single_request_timeout}}"
    meraki_certificate_path: "{{meraki_certificate_path}}"
    meraki_requests_proxy: "{{meraki_requests_proxy}}"
    meraki_wait_on_rate_limit: "{{meraki_wait_on_rate_limit}}"
    meraki_nginx_429_retry_wait_time: "{{meraki_nginx_429_retry_wait_time}}"
    meraki_action_batch_retry_wait_time: "{{meraki_action_batch_retry_wait_time}}"
    meraki_retry_4xx_error: "{{meraki_retry_4xx_error}}"
    meraki_retry_4xx_error_wait_time: "{{meraki_retry_4xx_error_wait_time}}"
    meraki_maximum_retries: "{{meraki_maximum_retries}}"
    meraki_output_log: "{{meraki_output_log}}"
    meraki_log_file_prefix: "{{meraki_log_file_prefix}}"
    meraki_log_path: "{{meraki_log_path}}"
    meraki_print_console: "{{meraki_print_console}}"
    meraki_suppress_logging: "{{meraki_suppress_logging}}"
    meraki_simulate: "{{meraki_simulate}}"
    meraki_be_geo_id: "{{meraki_be_geo_id}}"
    meraki_use_iterator_for_get_pages: "{{meraki_use_iterator_for_get_pages}}"
    meraki_inherit_logging_config: "{{meraki_inherit_logging_config}}"
    networkId: string
    clientId: string
  register: result

"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "id": "string",
      "mac": "string",
      "ip": "string",
      "ip6": "string",
      "description": "string",
      "firstSeen": 0,
      "lastSeen": 0,
      "manufacturer": "string",
      "os": "string",
      "user": "string",
      "vlan": "string",
      "ssid": "string",
      "switchport": "string",
      "wirelessCapabilities": "string",
      "smInstalled": true,
      "recentDeviceMac": "string",
      "clientVpnConnections": [
        {
          "remoteIp": "string",
          "connectedAt": 0,
          "disconnectedAt": 0
        }
      ],
      "lldp": [
        [
          "string"
        ]
      ],
      "cdp": [
        [
          "string"
        ]
      ],
      "status": "string"
    }
"""

==> ansible-10.1.0-2-any.pkg.tar.xz: usr/lib/python3.12/site-packages/ansible_collections/cisco/meraki/plugins/modules/networks_clients_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: networks_clients_info
short_description: Information module for networks _clients
description:
- Get networks _clients by id.
- >
   Return the client associated with the given identifier. Clients can be identified by a client key or either the
   MAC or IP depending on whether the network uses Track-by-IP.
version_added: '2.16.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  networkId:
    description:
    - NetworkId path parameter. Network ID.
    type: str
  clientId:
    description:
    - ClientId path parameter. Client ID.
    type: str
requirements:
- meraki >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco Meraki documentation for networks getNetworkClient
  description: Complete reference of the getNetworkClient API.
  link: https://developer.cisco.com/meraki/api-v1/#!get-network-client
notes:
  - SDK Method used are
    networks.Networks.get_network_client,

  - Paths used are
    get /networks/{networkId}/clients/{clientId},
"""

EXAMPLES = r"""
- name: Get networks _clients by id
  cisco.meraki.networks_clients_info:
    meraki_api_key: "{{meraki_api_key}}"
    meraki_base_url: "{{meraki_base_url}}"
    meraki_single_request_timeout: "{{meraki_single_request_timeout}}"
    meraki_certificate_path: "{{meraki_certificate_path}}"
    meraki_requests_proxy: "{{meraki_requests_proxy}}"
    meraki_wait_on_rate_limit: "{{meraki_wait_on_rate_limit}}"
    meraki_nginx_429_retry_wait_time: "{{meraki_nginx_429_retry_wait_time}}"
    meraki_action_batch_retry_wait_time: "{{meraki_action_batch_retry_wait_time}}"
    meraki_retry_4xx_error: "{{meraki_retry_4xx_error}}"
    meraki_retry_4xx_error_wait_time: "{{meraki_retry_4xx_error_wait_time}}"
    meraki_maximum_retries: "{{meraki_maximum_retries}}"
    meraki_output_log: "{{meraki_output_log}}"
    meraki_log_file_prefix: "{{meraki_log_file_prefix}}"
    meraki_log_path: "{{meraki_log_path}}"
    meraki_print_console: "{{meraki_print_console}}"
    meraki_suppress_logging: "{{meraki_suppress_logging}}"
    meraki_simulate: "{{meraki_simulate}}"
    meraki_be_geo_id: "{{meraki_be_geo_id}}"
    meraki_use_iterator_for_get_pages: "{{meraki_use_iterator_for_get_pages}}"
    meraki_inherit_logging_config: "{{meraki_inherit_logging_config}}"
    networkId: string
    clientId: string
  register: result

"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "cdp": [
        [
          "string"
        ]
      ],
      "clientVpnConnections": [
        {
          "connectedAt": 0,
          "disconnectedAt": 0,
          "remoteIp": "string"
        }
      ],
      "description": "string",
      "firstSeen": 0,
      "id": "string",
      "ip": "string",
      "ip6": "string",
      "lastSeen": 0,
      "lldp": [
        [
          "string"
        ]
      ],
      "mac": "string",
      "manufacturer": "string",
      "os": "string",
      "recentDeviceMac": "string",
      "smInstalled": true,
      "ssid": "string",
      "status": "string",
      "switchport": "string",
      "user": "string",
      "vlan": "string",
      "wirelessCapabilities": "string"
    }
"""
